==> qbittorrent_4.2.5.orig.tar.xz: qbittorrent-4.2.5/src/gui/tristateaction.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2019  Mike Tzou (Chocobo1)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#pragma once

#include <QWidgetAction>

class QString;
class QWidget;

class TriStateWidget;

// TriStateWidget is responsible for checkbox state (tri-state) and paint events while
// TriStateAction will keep in sync with it. This allows connecting with the usual
// QAction::triggered slot.
class TriStateAction : public QWidgetAction
{
public:
    TriStateAction(const QString &text, QWidget *parent);

    // should use this function instead of QAction::setChecked(bool)
    void setCheckState(Qt::CheckState checkState);

    void setCloseOnTriggered(bool enabled);

private:
    TriStateWidget *m_triStateWidget;
};

==> qbittorrent_4.4.1.orig.tar.xz: qbittorrent-4.4.1/src/gui/tristateaction.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2019  Mike Tzou (Chocobo1)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#pragma once

#include <QWidgetAction>

class QString;
class QWidget;

class TriStateWidget;

// TriStateWidget is responsible for checkbox state (tri-state) and paint events while
// TriStateAction will keep in sync with it. This allows connecting with the usual
// QAction::triggered or QAction::toggled slots.
class TriStateAction : public QWidgetAction
{
public:
    TriStateAction(const QString &text, QWidget *parent);

    // should use this function instead of QAction::setChecked(bool)
    void setCheckState(Qt::CheckState checkState);

    // When set to 'true' toggling the checkbox will emit a signal on
    // QAction::triggered. When placed in a QMenu, this causes the menu to close.
    // When set to 'false' emits a signal on QAction::toggled instead, leaving the
    // menu open.
    // Default value: 'true'.
    void setCloseOnInteraction(bool enabled);

private:
    TriStateWidget *m_triStateWidget;
};
